.editorconfig
.gitignore
.htaccess
README.md
accountdeleted.php
admin
api-docs.php
api.php
archive.php
config.php
diff.php
docs
generatepasswd.php
includes
index.php
install
langs
login.php
mail
oauth
pages.php
paste.php
profile.php
robots.txt
sitemap.xml
theme
upgrade
user.php